@@ -1,10 +1,10 @@
 import unittest
-from swml import SWMLResponse, AI, DataMap
+from swml import SignalWireML, AI, DataMap
 
 
 class TestSWMLAIUpdated(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_ai_method(self):
         main_section = self.response.add_section('main')
