@@ -1,9 +1,9 @@
-from swml import Cond, SWMLResponse
+from swml import Cond, SignalWireML
 import unittest
 
 class TestSWMLCond(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_cond_method(self):
         main_section = self.response.add_section('main')
