@@ -1,10 +1,10 @@
 import unittest
-from swml import SWMLResponse, Denoise
+from swml import SignalWireML, Denoise
 
 
 class TestDenoise(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_denoise_with_instance(self):
         main_section = self.response.add_section('main')
