@@ -1,9 +1,9 @@
-from swml import SWMLResponse, JoinRoom
+from swml import SignalWireML, JoinRoom
 import unittest
 
 class TestSWMLJoinRoom(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_join_room_method(self):
         main_section = self.response.add_section('main')
