@@ -1,9 +1,9 @@
-from swml import SWMLResponse, Play
+from swml import SignalWireML, Play
 import unittest
 
 class TestSWMLPlay(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_play_method(self):
         main_section = self.response.add_section('main')
