@@ -1,9 +1,9 @@
 import unittest
-from swml import SWMLResponse, ReceiveFax
+from swml import SignalWireML, ReceiveFax
 
 class TestReceiveFax(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_receive_fax_with_instance(self):
         main_section = self.response.add_section('main')
