@@ -1,9 +1,9 @@
 import unittest
-from swml import SWMLResponse, Return
+from swml import SignalWireML, Return
 
 class TestSWMLReturn(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_return_method(self):
         main_section = self.response.add_section('main')
