@@ -1,9 +1,9 @@
 import unittest
-from swml import SWMLResponse, SendDigits
+from swml import SignalWireML, SendDigits
 
 class TestSWMLSendDigits(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_send_digits_method(self):
         main_section = self.response.add_section('main')
