@@ -1,9 +1,9 @@
 import unittest
-from swml import SWMLResponse, SendFax
+from swml import SignalWireML, SendFax
 
 class TestSendFax(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_send_fax_with_instance(self):
         main_section = self.response.add_section('main')
