@@ -1,9 +1,9 @@
 import unittest
-from swml import SWMLResponse, SendSMS
+from swml import SignalWireML, SendSMS
 
 class TestSWMLSendSMS(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_send_sms_method(self):
         main_section = self.response.add_section('main')
