@@ -1,9 +1,9 @@
 import unittest
-from swml import SWMLResponse, StopDenoise
+from swml import SignalWireML, StopDenoise
 
 class TestStopDenoise(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_stop_denoise_with_instance(self):
         main_section = self.response.add_section('main')
