@@ -1,10 +1,10 @@
-from swml import StopRecordCall, SWMLResponse
+from swml import StopRecordCall, SignalWireML
 import unittest
 
 
 class TestSWMLStopRecordCall(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_stop_record_call_method(self):
         main_section = self.response.add_section('main')
