@@ -1,9 +1,9 @@
 import unittest
-from swml import SWMLResponse, StopTap
+from swml import SignalWireML, StopTap
 
 class TestSWMLStopTap(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_stop_tap_method(self):
         main_section = self.response.add_section('main')
