@@ -1,9 +1,9 @@
 import unittest
-from swml import SWMLResponse, Tap
+from swml import SignalWireML, Tap
 
 class TestSWMLTap(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_tap_method(self):
         main_section = self.response.add_section('main')
