@@ -1,9 +1,9 @@
 import unittest
-from swml import SWMLResponse, Unset
+from swml import SignalWireML, Unset
 
 class TestSWMLUnset(unittest.TestCase):
     def setUp(self):
-        self.response = SWMLResponse()
+        self.response = SignalWireML()
 
     def test_unset_method(self):
         main_section = self.response.add_section('main')
@@ -13,7 +13,7 @@ class TestSWMLUnset(unittest.TestCase):
 
     def test_add_instruction_with_unset_instance(self):
         main_section = self.response.add_section('main')
-        unset_instruction = Unset(_vars="var1")
+        unset_instruction = Unset(vars_="var1")
         main_section.add_instruction(unset_instruction)
         expected_swml = '{"sections": {"main": [{"unset": {"vars": "var1"}}]}}'
         self.assertEqual(self.response.generate_swml(), expected_swml)
